"""Constants for the provided JDBC drivers.

To use another JDBC driver, add its JAR to the :attr:`~atoti.SessionConfig.extra_jars`.

Example:
    Storing user content in Google BigQuery:

    >>> import glob
    >>> from atoti_jdbc import UserContentStorageConfig
    >>> user_content_storage_config = UserContentStorageConfig(
    ...     "jdbc:bigquery://https://www.googleapis.com/bigquery/v2:443;ProjectId=PROJECT_ID;OAuthType=0;OAuthServiceAcctEmail=EMAIL_OF_SERVICEACCOUNT;OAuthPvtKeyPath=path/to/json/keys;",
    ...     driver="com.simba.googlebigquery.jdbc42.Driver",
    ... )
    >>> session_config = tt.SessionConfig(
    ...     extra_jars=glob.glob("./odbc_jdbc_drivers/*.jar"),
    ...     user_content_storage=user_content_storage_config,
    ... )

"""

from atoti._jdbc import H2_DRIVER as _H2_DRIVER

H2_DRIVER = _H2_DRIVER
"""H2 driver."""

IBM_DB2_DRIVER = "com.ibm.db2.jcc.DB2Driver"
"""IBM Db2 driver."""

MARIADB_DRIVER = "org.mariadb.jdbc.Driver"
"""MariaDB driver."""

MSSQL_DRIVER = "com.microsoft.sqlserver.jdbc.SQLServerDriver"
"""Microsoft SQL Server driver."""

MYSQL_DRIVER = "com.mysql.cj.jdbc.Driver"
"""MySQL driver."""

ORACLE_DRIVER = "oracle.jdbc.OracleDriver"
"""Oracle driver."""

POSTGRESQL_DRIVER = "org.postgresql.Driver"
"""PostgreSQL driver."""
